==> libapache-mod-mp3_0.35.orig.tar.gz: libapache-mod-mp3-0.35.orig/src/directives.h <==
#define MP3Engine "Use this to turn on and off the mp3 steaming server."
#define MP3Loop "Causes the connectio loop."
#define MP3Random "Use this to turn on and off random mp3."
#define MP3LimitPlayConnections "Sets the number of connections for sending data."
#define MP3Cache "Use this to turn on and off caching mp3 (you better have some memory)."
#define MP3 "Takes either a filename, or a directory name to read files from."
#define MP3PlayList "Takes a file and loads each line into the server as a file (this is the standard file format for playlists)."
#define MP3Genre "What genre the music is."
#define MP3DefaultOperation "Default operation."
#define MP3Log "Log for connections."
#define MP3Stream "If turned on, connections will expect a stream to provide data."
#define MP3Encoder "Example: MP3Encoder \"/usr/local/bin/lame -q 2 -b 48 --silent % -\""
#define MP3CastName "What is the name of the feed."
#define MP3MimeType "What should the default content of the feed be."
#define MP3ReloadRequest "This takes no value, it will cause the server to reload all directories/files/playlists for each connection. Be careful about using this since it can really kill performance. Cache can not be enabled while using this."
#define MP3Allow "Filenames to allow."
#define MP3Deny "Filename to deny"
#define MP3DispatchAgent "We default to the internal types."
#ifdef MYSQL_ENABLED
#define MP3MySQLConnectInfo "Host, user and password for connecting to database (defaults to localhost, null, and null)."
#define MP3MySQLInfo "This takes the db name and the table name."
#define MP3MySQLTokenTable "This takes the table name used for tokens."
#endif

==> libapache-mod-mp3_0.39.orig.tar.gz: libapache-mod-mp3-0.39.orig/src/directives.h <==
#define MP3Engine "Use this to turn on and off the mp3 steaming server."
#define MP3Loop "Causes the connectio loop."
#define MP3Random "Use this to turn on and off random mp3."
#define MP3LimitPlayConnections "Sets the number of connections for sending data."
#define MP3LimitBytesPerTrack "Sets the maximum number of bytes to send from one track."
#define MP3Cache "Use this to turn on and off caching mp3 (you better have some memory)."
#define MP3 "Takes either a filename, or a directory name to read files from."
#define MP3PlayList "Takes a file and loads each line into the server as a file (this is the standard file format for playlists)."
#define MP3Genre "What genre the music is."
#define MP3DefaultOperation "Default operation."
#define MP3Log "Log for connections."
#define MP3Stream "If turned on, connections will expect a stream to provide data."
#define MP3Encoder "Example: MP3Encoder \"/usr/local/bin/lame -q 2 -b 48 --silent % -\""
#define MP3CastName "What is the name of the feed."
#define MP3MimeType "What should the default content of the feed be."
#define MP3ReloadRequest "This takes no value, it will cause the server to reload all directories/files/playlists for each connection. Be careful about using this since it can really kill performance. Cache can not be enabled while using this."
#define MP3Allow "Filenames to allow."
#define MP3Deny "Filename to deny"
#define MP3DispatchAgent "We default to the internal type."
#define MP3DirectoryServer "Takes a URL to a yp server and an optional \"on\" if you don't want mod_mp3 to insert its own info." 
#ifdef MYSQL_ENABLED
#define MP3MySQLConnectInfo "Host, user and password for connecting to database (defaults to localhost, null, and null)."
#define MP3MySQLInfo "This takes the db name and the table name."
#define MP3MySQLTokenTable "This takes the table name used for tokens."
#endif
#ifdef PG_ENABLED
#define MP3PgConnectInfo "Host, user and password for connecting to database (defaults to localhost, null, and null)."
#define MP3PgInfo "This takes the db name and the table name."
#define MP3PgTokenTable "This takes the table name used for tokens."
#endif
